@@ -22,29 +22,16 @@
 #ifndef NOTIFY_DAEMON_H
 #define NOTIFY_DAEMON_H
 
-#include <tqwidget.h>
-#include <kpassivepopup.h>
-
-class NotifierContainer : public TQWidget
+class TDEUI_EXPORT NotificationContainer : public TDEPassivePopupStackContainer
 {
 	Q_OBJECT
-	
 
-public:
-	NotifierContainer();
-	~NotifierContainer();
+	public:
+		NotificationContainer();
+		~NotificationContainer();
 
-	void displayMessage(TQString title, TQString message, TQString icon, int x, int y);
-	void processEvents();
-
-public slots:
-	void handleGTKMain();
-	void popupClosed(KPassivePopup*);
-
-private:
-	TQPtrList<KPassivePopup> mPopupList;
-	long mTopOfStack;
-	long mRightOfStack;
+	public slots:
+		void handleGTKMain();
 };
 
 #include <glib.h>
